package de.szut.casino.user.transaction;

import de.szut.casino.deposit.TransactionEntity;
import de.szut.casino.deposit.TransactionRepository;
import de.szut.casino.user.UserEntity;
import de.szut.casino.user.UserService;
import de.szut.casino.user.transaction.dto.GetTransactionDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class GetTransactionService {

    @Autowired
    private UserService userService;

    @Autowired
    private TransactionRepository transactionRepository;

    public List<TransactionEntity> getUserTransactions(String authToken, Integer limit) {
        Optional<UserEntity> user = this.userService.getCurrentUser(authToken);
        if (user.isPresent()) {
            if (limit != null && limit > 0) {
                return this.transactionRepository.findByUserIdWithLimit(user.get(), limit);
            } else {
                return this.transactionRepository.findAllByUserId(user.get());
            }
        }

        return List.of();
    }

    public List<GetTransactionDto> mapTransactionsToDtos(List<TransactionEntity> transactions) {
        return transactions.stream()
                .map(transaction -> new GetTransactionDto(
                        transaction.getAmount(),
                        transaction.getStatus(),
                        transaction.getCreatedAt())
                ).toList();
    }
}

